"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SignPosition_1 = require("./SignPosition");
const SignBackground_1 = require("./SignBackground");
class Sign {
    constructor(options) {
        this.options = options;
        this.background = new SignBackground_1.SignBackground(options.preventContentClicking, options.onBackgroundClick);
        this.root = document.createElement('DIV');
        this.root.classList.add('sign', 'hide-sign');
        document.body.appendChild(this.root);
    }
    isVisible() {
        return !this.root.classList.contains('hide-sign');
    }
    hide() {
        this.root.classList.add('hide-sign');
        this.background.hide();
    }
    show() {
        this.root.classList.remove('hide-sign');
        this.background.show();
    }
    _getOptions(actor) {
        const options = actor.options;
        let nOptions = Object.assign({}, this.options);
        Object.assign(nOptions, options);
        return nOptions;
    }
    setContent(actor) {
        const nOptions = this._getOptions(actor);
        if (nOptions.signHTML.length !== 0) {
            this.root.innerHTML = nOptions.signHTML;
        }
        else {
            this.root.innerHTML = `<h4>${nOptions.signTitle}</h4><p>${nOptions.signText}</p>`;
        }
    }
    setHTMLMessage(actor) {
        const information = actor.getInformation();
        const nOptions = this._getOptions(actor);
        if (!this.isVisible() && nOptions.showSign) {
            this._setPosition(nOptions.signPosition, information);
            this.show();
        }
    }
    _setPosition(position, information) {
        const style = getComputedStyle(this.root);
        let height = +style.height.substr(0, style.height.length - 2);
        let width = +style.width.substr(0, style.width.length - 2);
        this.root.classList.remove('sign-right', 'sign-left', 'sign-top', 'sign-bottom');
        switch (position) {
            case SignPosition_1.SignPosition.RIGHT:
                this.root.style.left = information.position.x + information.position.width + 20 + 'px';
                this.root.style.top = information.position.y + information.position.height / 2 - +height / 2 + 'px';
                this.root.classList.add('sign-right');
                break;
            case SignPosition_1.SignPosition.LEFT:
                this.root.style.left = +(information.position.x - width) - 2 * 20 + 'px'; // TODO fix
                this.root.style.top = information.position.y + information.position.height / 2 - +height / 2 + 'px';
                this.root.classList.add('sign-left');
                break;
            case SignPosition_1.SignPosition.TOP:
                this.root.style.left = +(information.position.x + information.position.width / 2 - width / 2) + 'px';
                this.root.style.top = information.position.y - height - 20 + 'px';
                this.root.classList.add('sign-top');
                break;
            case SignPosition_1.SignPosition.BOTTOM:
                this.root.style.left = +(information.position.x + information.position.width / 2 - width / 2) + 'px';
                this.root.style.top = information.position.y + information.position.height + 20 + 'px';
                this.root.classList.add('sign-bottom');
                break;
            default:
                throw new Error('not implemented');
        }
    }
}
exports.Sign = Sign;
